.. _auxiliary_progs:

=======================================
auxiliary programs
=======================================

These auxiliary programs are installed as part of `phydms`_. All of them can be run from the command line. They aid in running multiple analyses with :ref:`phydms_prog`, or in analyzing and visualizing the results.

.. toctree::
   :maxdepth: 1

   phydms_comprehensive_prog
   phydms_prepalignment
   phydms_logoplot

.. include:: weblinks.txt
   
